@@ -18,6 +18,13 @@ ukLang %>% separate(key, into = c("region", "language", "statistic"), sep = " >>
 url <- "http://en.wikipedia.org/wiki/New_Zealand_general_election,_2002"
 xp <- "//caption[starts-with(text(), 'Electorate results')]/ancestor::table"
 
-nz1 <- htmltab(doc = url, which = xp, body = "//tr[./td[not(@colspan = '10')]]")
+nz1 <- htmltab(doc = url, which = xp, encoding = "UTF-8")
 head(nz1)
 
+## ------------------------------------------------------------------------
+nz2 <- htmltab(doc = url, which = xp, header = 1 + "//tr/td[@colspan = '10']",
+               body = "//tr[./td[not(@colspan = '10')]]", encoding = "UTF-8")
+
+## ------------------------------------------------------------------------
+tail(nz2, 9)
+
