@@ -6,13 +6,12 @@ test_that("Prompts errors correctly", {
 
 test_that("check_type produces class output", {
 
-  x <- check_type(doc = "http://en.wikipedia.org/wiki/Indian_general_election,_2014", which = "//table[5]")
+  x <- check_type(doc = "http://christianrubba.com/htmltab/ex/wiki_indian_election2014.html", which = "//table[5]")
   expect_that(x, is_a("XMLInternalDocument"))
 
-  y <- check_type(doc = "http://en.wikipedia.org/wiki/Indian_general_election,_2014", which = NULL)
-  expect_that(y, is_a("XMLInternalDocument"))
+  expect_error(check_type(doc = "http://christianrubba.com/htmltab/ex/wiki_indian_election2014.html", which = 1))
 
-  parsed <- XML::htmlParse("http://en.wikipedia.org/wiki/Indian_general_election,_2014")
+  parsed <- XML::htmlParse("http://christianrubba.com/htmltab/ex/wiki_indian_election2014.html")
   z <- check_type(doc = parsed, which = 3)
   expect_that(z, is_a("XMLInternalDocument"))
 })
